@@ -49,9 +49,6 @@ def main_options(parser):
         help='set the strength of the blur applied to a frame before being compared.')
 
     parser.add_argument('urlOps', nargs=0, action='grouping')
-    parser.add_argument('--format', type=str, group='urlOps',
-        default='bestvideo[ext=mp4]+bestaudio[ext=m4a]/mp4',
-        help='the format youtube-dl uses to when downloading a url.')
     parser.add_argument('--output_dir', type=str, group='urlOps',
         default=None,
         help='the directory where the downloaded file is placed.')
@@ -273,8 +270,8 @@ def main():
         print('Python Version: {} {}'.format(platform.python_version(), is64bit))
         print('Platform: {} {}'.format(platform.system(), platform.release()))
         print('Config File path: {}'.format(os.path.join(dirpath, 'config.txt')))
-        print('FFmpeg path: {}'.format(ffmpeg.getPath()))
-        print('FFmpeg version: {}'.format(ffmpeg.version()))
+        print('FFmpeg path: {}'.format(ffmpeg.path))
+        print('FFmpeg version: {}'.format(ffmpeg.version))
         print('Auto-Editor version {}'.format(auto_editor.version))
         sys.exit()
 
@@ -361,7 +358,7 @@ def main():
     if(args.output_file is None):
         args.output_file = []
 
-    from auto_editor.validateInput import valid_input
+    from auto_editor.validate_input import valid_input
     input_list, segments = valid_input(args.input, ffmpeg, args, log)
 
     if(len(args.output_file) < len(input_list)):
