@@ -18,11 +18,8 @@ def out(text):
     import re
     import textwrap
 
-    try:
-        from shutil import get_terminal_size
-        width = get_terminal_size().columns - 3
-    except ImportError:
-        width = 77
+    from shutil import get_terminal_size
+    width = get_terminal_size().columns - 3
 
     indent_regex = re.compile(r'^(\s+)')
     wrapped_lines = []
@@ -43,10 +40,20 @@ def print_option_help(args, option):
         text += '  {}:\n'.format(option['names'][0])
     else:
         text += '  ' + ', '.join(option['names']) + '\n    ' + option['help'] + '\n\n'
+        if(option['keywords'] != []):
+            text += '    Arguments:\n    '
+            for n, item in enumerate(option['keywords']):
+                [[k, v]] = item.items()
+                text += '{' + k
+                text += '' if v == '' else '=' + str(v)
+                text += '}' if n + 1 == len(option['keywords']) else '},'
+
         if(option['extra'] != ''):
             text += '{}\n\n'.format(indent(option['extra'], '    '))
 
-    if(option['action'] == 'default'):
+    if(option['keywords'] != []):
+        pass
+    elif(option['action'] == 'default'):
         text += '    type: ' + option['type'].__name__
         text += '\n    default: {}\n'.format(option['default'])
         if(option['range'] is not None):
@@ -72,16 +79,17 @@ def print_program_help(root, the_args):
     text = ''
     for options in the_args:
         for option in options:
-            if(option['action'] == 'grouping'):
-                text += "\n  {}:\n".format(option['names'][0])
-            else:
-                text += '  ' + ', '.join(option['names']) + ': ' + option['help'] + '\n'
+            if(not option['hidden']):
+                if(option['action'] == 'grouping'):
+                    text += "\n  {}:\n".format(option['names'][0])
+                else:
+                    text += '  ' + ', '.join(option['names']) + ': ' + option['help'] + '\n'
     text += '\n'
     if(root == 'auto-editor'):
-        text += '  Have an issue? Make an issue. Visit '\
-            'https://github.com/wyattblue/auto-editor/issues\n\n  The help option '\
-            'can also be used on a specific option:\n     auto-editor '\
-            '--frame_margin --help\n'
+        text += ('  Have an issue? Make an issue. Visit '
+            'https://github.com/wyattblue/auto-editor/issues\n\n  The help option '
+            'can also be used on a specific option:\n     auto-editor '
+            '--frame_margin --help\n')
     out(text)
 
 def get_option(item, group, the_args):
@@ -113,6 +121,8 @@ class ArgumentParser():
             'choices': None,
             'group': None,
             'help': '',
+            'keywords': [],
+            'hidden': False,
             'extra': '',
         }
 
@@ -143,8 +153,42 @@ class ArgumentParser():
         return ParseOptions(sys_args, log, root, self.args)
 
 
+"""
+    Positional Arguments
+        --rectangle 0,end,10,20,20,30,#000, ...
+
+    Keyword Arguments
+        --rectangle start=0,end=end,x1=10, ...
+
+"""
+
 class ParseOptions():
 
+    def parse_parameters(self, val, op):
+
+        # TODO: allow out-of-order arguments with keyword syntax.
+
+        dic = {}
+        keys = []
+        for key in op['keywords']:
+            [[k, v]] = key.items()
+            keys.append(k)
+            dic[k] = v
+
+        for i, item in enumerate(val.split(',')):
+            if(i+1 > len(keys)):
+                print(f"Error! Too many arguments, starting with '{item}'", file=sys.stderr)
+                sys.exit(1)
+
+            dic[keys[i]] = item
+
+        # Check if any positional args are not specified.
+        for key, item in dic.items():
+            if(item == ''):
+                print(f"Error! parameter '{key}' is required.", file=sys.stderr)
+                sys.exit(1)
+        return dic
+
     def setConfig(self, config_path, root):
         if(not os.path.isfile(config_path)):
             return
@@ -243,6 +287,11 @@ class ParseOptions():
                 # Unknown Option!
                 if(setting_inputs and (option_list != 'input' or (option_list == 'input' and not item.startswith('-')))):
                     # Option is actually an input file, like example.mp4
+
+                    if(option_list != 'input'):
+                        _op = used_options[-1]
+                        if(_op['keywords'] != []):
+                            item = self.parse_parameters(item, _op)
                     my_list.append(item)
                 else:
                     log.error(error_message(args, item, label))
@@ -255,10 +304,10 @@ class ParseOptions():
                 option_list = None
                 my_list = []
 
-                if(option['names'][0] in used_options):
+                if(option in used_options):
                     log.error('Cannot repeat option {} twice.'.format(option['names'][0]))
 
-                used_options.append(option['names'][0])
+                used_options.append(option)
 
                 key = _to_key(option)
                 _set.append(key)
